summaryrefslogtreecommitdiff
path: root/libpcsxcore/cdriso.c
diff options
context:
space:
mode:
authorSND\weimingzhi_cp <SND\weimingzhi_cp@e17a0e51-4ae3-4d35-97c3-1a29b211df97>2010-07-10 06:54:11 +0000
committerSND\weimingzhi_cp <SND\weimingzhi_cp@e17a0e51-4ae3-4d35-97c3-1a29b211df97>2010-07-10 06:54:11 +0000
commitf7823bc1646f1885bd9a0a19a9645c0e2cb884bd (patch)
tree15f115383205088b3fca3f4c41a319e1da183ac7 /libpcsxcore/cdriso.c
parentfcf4fb0933140db08c7bc094abc9edb271c13359 (diff)
downloadpcsxr-f7823bc1646f1885bd9a0a19a9645c0e2cb884bd.tar.gz
I was really stupid... just use libcdio and everything's fine, no need to deal with different OSes at all.
git-svn-id: https://pcsxr.svn.codeplex.com/svn/pcsxr@54442 e17a0e51-4ae3-4d35-97c3-1a29b211df97
Diffstat (limited to 'libpcsxcore/cdriso.c')
-rw-r--r--libpcsxcore/cdriso.c78
1 files changed, 13 insertions, 65 deletions
diff --git a/libpcsxcore/cdriso.c b/libpcsxcore/cdriso.c
index dc1f6bf3..18b0de92 100644
--- a/libpcsxcore/cdriso.c
+++ b/libpcsxcore/cdriso.c
@@ -35,7 +35,7 @@ static FILE *cdHandle = NULL;
static FILE *cddaHandle = NULL;
static FILE *subHandle = NULL;
-static boolean subChanInterleaved = FALSE;
+static boolean subChanMixed = FALSE;
static boolean subChanRaw = FALSE;
static unsigned char cdbuffer[DATA_SIZE];
@@ -160,7 +160,7 @@ static void *playthread(void *param)
t = GetTickCount() + CDDA_FRAMETIME;
- if (subChanInterleaved) {
+ if (subChanMixed) {
s = 0;
for (i = 0; i < sizeof(sndbuffer) / CD_FRAMESIZE_RAW; i++) {
@@ -320,10 +320,10 @@ static int parsetoc(const char *isofile) {
ti[numtracks].type = DATA;
sec2msf(2 * 75, ti[numtracks].start); // assume data track on 0:2:0
// check if this image contains interleaved subchannel data
token = strtok(NULL, " ");
if (token != NULL && !strncmp(token, "RW_RAW", 6)) {
- subChanInterleaved = TRUE;
+ subChanMixed = TRUE;
subChanRaw = TRUE;
}
}
@@ -334,7 +334,7 @@ static int parsetoc(const char *isofile) {
else if (!strcmp(token, "DATAFILE")) {
if (ti[numtracks].type == CDDA) {
sscanf(linebuf, "DATAFILE \"%[^\"]\" #%d %8s", name, &t, time2);
- t /= CD_FRAMESIZE_RAW + (subChanInterleaved ? SUB_FRAMESIZE : 0);
+ t /= CD_FRAMESIZE_RAW + (subChanMixed ? SUB_FRAMESIZE : 0);
t += 2 * 75;
sec2msf(t, (char *)&ti[numtracks].start);
tok2msf((char *)&time2, (char *)&ti[numtracks].length);
@@ -347,7 +347,7 @@ static int parsetoc(const char *isofile) {
else if (!strcmp(token, "FILE")) {
sscanf(linebuf, "FILE \"%[^\"]\" #%d %8s %8s", name, &t, time, time2);
tok2msf((char *)&time, (char *)&ti[numtracks].start);
- t /= CD_FRAMESIZE_RAW + (subChanInterleaved ? SUB_FRAMESIZE : 0);
+ t /= CD_FRAMESIZE_RAW + (subChanMixed ? SUB_FRAMESIZE : 0);
t += msf2sec(ti[numtracks].start) + 2 * 75;
sec2msf(t, (char *)&ti[numtracks].start);
tok2msf((char *)&time2, (char *)&ti[numtracks].length);
@@ -571,9 +571,9 @@ static int parsemds(const char *isofile) {
offset += 0x50;
}
// check if the image contains interleaved subchannel data
fseek(fi, offset + 1, SEEK_SET);
- subChanInterleaved = (fgetc(fi) ? TRUE : FALSE);
+ subChanMixed = (fgetc(fi) ? TRUE : FALSE);
// read track data
for (i = 1; i <= numtracks; i++) {
@@ -677,7 +677,7 @@ static long CALLBACK ISOopen(void) {
SysPrintf(_("Loaded CD Image: %s"), GetIsoFile());
cddaBigEndian = FALSE;
- subChanInterleaved = FALSE;
+ subChanMixed = FALSE;
subChanRaw = FALSE;
if (parsecue(GetIsoFile()) == 0) {
@@ -693,7 +693,7 @@ static long CALLBACK ISOopen(void) {
SysPrintf("[+mds]");
}
- if (!subChanInterleaved && opensubfile(GetIsoFile()) == 0) {
+ if (!subChanMixed && opensubfile(GetIsoFile()) == 0) {
SysPrintf("[+sub]");
}
@@ -754,50 +754,6 @@ static long CALLBACK ISOgetTD(unsigned char track, unsigned char *buffer) {
return 0;
}
-// lookup table for crc calculation
-static unsigned short crctab[256] = {
- 0x0000, 0x1021, 0x2042, 0x3063, 0x4084, 0x50A5, 0x60C6, 0x70E7, 0x8108,
- 0x9129, 0xA14A, 0xB16B, 0xC18C, 0xD1AD, 0xE1CE, 0xF1EF, 0x1231, 0x0210,
- 0x3273, 0x2252, 0x52B5, 0x4294, 0x72F7, 0x62D6, 0x9339, 0x8318, 0xB37B,
- 0xA35A, 0xD3BD, 0xC39C, 0xF3FF, 0xE3DE, 0x2462, 0x3443, 0x0420, 0x1401,
- 0x64E6, 0x74C7, 0x44A4, 0x5485, 0xA56A, 0xB54B, 0x8528, 0x9509, 0xE5EE,
- 0xF5CF, 0xC5AC, 0xD58D, 0x3653, 0x2672, 0x1611, 0x0630, 0x76D7, 0x66F6,
- 0x5695, 0x46B4, 0xB75B, 0xA77A, 0x9719, 0x8738, 0xF7DF, 0xE7FE, 0xD79D,
- 0xC7BC, 0x48C4, 0x58E5, 0x6886, 0x78A7, 0x0840, 0x1861, 0x2802, 0x3823,
- 0xC9CC, 0xD9ED, 0xE98E, 0xF9AF, 0x8948, 0x9969, 0xA90A, 0xB92B, 0x5AF5,
- 0x4AD4, 0x7AB7, 0x6A96, 0x1A71, 0x0A50, 0x3A33, 0x2A12, 0xDBFD, 0xCBDC,
- 0xFBBF, 0xEB9E, 0x9B79, 0x8B58, 0xBB3B, 0xAB1A, 0x6CA6, 0x7C87, 0x4CE4,
- 0x5CC5, 0x2C22, 0x3C03, 0x0C60, 0x1C41, 0xEDAE, 0xFD8F, 0xCDEC, 0xDDCD,
- 0xAD2A, 0xBD0B, 0x8D68, 0x9D49, 0x7E97, 0x6EB6, 0x5ED5, 0x4EF4, 0x3E13,
- 0x2E32, 0x1E51, 0x0E70, 0xFF9F, 0xEFBE, 0xDFDD, 0xCFFC, 0xBF1B, 0xAF3A,
- 0x9F59, 0x8F78, 0x9188, 0x81A9, 0xB1CA, 0xA1EB, 0xD10C, 0xC12D, 0xF14E,
- 0xE16F, 0x1080, 0x00A1, 0x30C2, 0x20E3, 0x5004, 0x4025, 0x7046, 0x6067,
- 0x83B9, 0x9398, 0xA3FB, 0xB3DA, 0xC33D, 0xD31C, 0xE37F, 0xF35E, 0x02B1,
- 0x1290, 0x22F3, 0x32D2, 0x4235, 0x5214, 0x6277, 0x7256, 0xB5EA, 0xA5CB,
- 0x95A8, 0x8589, 0xF56E, 0xE54F, 0xD52C, 0xC50D, 0x34E2, 0x24C3, 0x14A0,
- 0x0481, 0x7466, 0x6447, 0x5424, 0x4405, 0xA7DB, 0xB7FA, 0x8799, 0x97B8,
- 0xE75F, 0xF77E, 0xC71D, 0xD73C, 0x26D3, 0x36F2, 0x0691, 0x16B0, 0x6657,
- 0x7676, 0x4615, 0x5634, 0xD94C, 0xC96D, 0xF90E, 0xE92F, 0x99C8, 0x89E9,
- 0xB98A, 0xA9AB, 0x5844, 0x4865, 0x7806, 0x6827, 0x18C0, 0x08E1, 0x3882,
- 0x28A3, 0xCB7D, 0xDB5C, 0xEB3F, 0xFB1E, 0x8BF9, 0x9BD8, 0xABBB, 0xBB9A,
- 0x4A75, 0x5A54, 0x6A37, 0x7A16, 0x0AF1, 0x1AD0, 0x2AB3, 0x3A92, 0xFD2E,
- 0xED0F, 0xDD6C, 0xCD4D, 0xBDAA, 0xAD8B, 0x9DE8, 0x8DC9, 0x7C26, 0x6C07,
- 0x5C64, 0x4C45, 0x3CA2, 0x2C83, 0x1CE0, 0x0CC1, 0xEF1F, 0xFF3E, 0xCF5D,
- 0xDF7C, 0xAF9B, 0xBFBA, 0x8FD9, 0x9FF8, 0x6E17, 0x7E36, 0x4E55, 0x5E74,
- 0x2E93, 0x3EB2, 0x0ED1, 0x1EF0
-};
-
-static unsigned short calcCrc(unsigned char *d, int len) {
- unsigned short crc = 0;
- int i;
-
- for (i = 0; i < len; i++) {
- crc = crctab[(crc >> 8) ^ d[i]] ^ (crc << 8);
- }
-
- return ~crc;
-}
-
// decode 'raw' subchannel data ripped by cdrdao
static void DecodeRawSubData(void) {
unsigned char subQData[12];
@@ -822,16 +778,12 @@ static long CALLBACK ISOreadTrack(unsigned char *time) {
return -1;
}
- if (subChanInterleaved) {
+ if (subChanMixed) {
fseek(cdHandle, MSF2SECT(btoi(time[0]), btoi(time[1]), btoi(time[2])) * (CD_FRAMESIZE_RAW + SUB_FRAMESIZE) + 12, SEEK_SET);
fread(cdbuffer, 1, DATA_SIZE, cdHandle);
fread(subbuffer, 1, SUB_FRAMESIZE, cdHandle);
if (subChanRaw) DecodeRawSubData();
-
- if ((((u16)subbuffer[22] << 8) | (u16)subbuffer[23]) != calcCrc(&subbuffer[12], 10)) {
- memset(&subbuffer[15], 0, 7); // CRC wrong, wipe out time data
- }
}
else {
fseek(cdHandle, MSF2SECT(btoi(time[0]), btoi(time[1]), btoi(time[2])) * CD_FRAMESIZE_RAW + 12, SEEK_SET);
@@ -842,10 +794,6 @@ static long CALLBACK ISOreadTrack(unsigned char *time) {
fread(subbuffer, 1, SUB_FRAMESIZE, subHandle);
if (subChanRaw) DecodeRawSubData();
-
- if ((((u16)subbuffer[22] << 8) | (u16)subbuffer[23]) != calcCrc(&subbuffer[12], 10)) {
- memset(&subbuffer[15], 0, 7); // CRC wrong, wipe out time data
- }
}
}
@@ -862,7 +810,7 @@ static unsigned char * CALLBACK ISOgetBuffer(void) {
// does NOT uses bcd format
static long CALLBACK ISOplay(unsigned char *time) {
if (SPU_playCDDAchannel != NULL) {
- if (subChanInterleaved) {
+ if (subChanMixed) {
startCDDA(MSF2SECT(time[0], time[1], time[2]) * (CD_FRAMESIZE_RAW + SUB_FRAMESIZE));
}
else {
@@ -880,7 +828,7 @@ static long CALLBACK ISOstop(void) {
// gets subchannel data
static unsigned char* CALLBACK ISOgetBufferSub(void) {
- if (subHandle != NULL || subChanInterleaved) {
+ if (subHandle != NULL || subChanMixed) {
return subbuffer;
}
@@ -320,10 +320,10 @@ static int parsetoc(const char *isofile) {
ti[numtracks].type = DATA;
sec2msf(2 * 75, ti[numtracks].start); // assume data track on 0:2:0
- // check if this image contains interleaved subchannel data
+ // check if this image contains mixed subchannel data
token = strtok(NULL, " ");
if (token != NULL && !strncmp(token, "RW_RAW", 6)) {
@@ -571,9 +571,9 @@ static int parsemds(const char *isofile) {
offset += 0x50;
}
- // check if the image contains interleaved subchannel data
+ // check if the image contains mixed subchannel data
fseek(fi, offset + 1, SEEK_SET);